const typingDiv = document.createElement('div');
typingDiv.className = 'chatbox-message reply';
typingDiv.innerHTML = '<span></span><span></span><span></span>';

function displayStep(step, userResponse = null) {
    const chat = document.getElementById('chatbox-content');

    // Create initial bot reply container for the first typing indicator
    const initialBotReplyDiv = document.createElement('div');
    initialBotReplyDiv.className = 'chatbox bot-reply';

    if (!userResponse) {
        chat.appendChild(initialBotReplyDiv);
    }

    // Create bot reply container
    const botReplyDiv = document.createElement('div');
    botReplyDiv.className = 'chatbox bot-reply';

    const stepData = chatData.chatFlow[step];

    if (stepData) {
        // Display user's previous response, if any
        if (!userResponse) {
            typingDiv.style.display = 'block';
        }

        if (userResponse) {
            const userReplyDiv = document.createElement('div');
            userReplyDiv.className = 'chatbox user-reply';
            userReplyDiv.innerHTML = `<div class="chatbox-message">${userResponse}</div>`;
            chat.appendChild(userReplyDiv);
        }

        initialBotReplyDiv.appendChild(typingDiv);

        // Function to process each message with a delay
        const processMessage = (msg, index, totalMessages, botReplyDiv) => {

            if (index == 0) {
                chat.appendChild(botReplyDiv);
                typingDiv.style.display = 'block';
            }

            if (!userResponse) {
                typingDiv.style.display = 'block';
            }

            setTimeout(() => {
                typingDiv.style.display = 'none';

                const messageDiv = document.createElement('div');
                messageDiv.className = 'chatbox-message';

                // Determine message type and set content
                if (typeof msg === 'string') {
                    messageDiv.innerHTML = `<p>${msg}</p>`;
                } else if (msg.type === 'link') {
                    messageDiv.innerHTML = `<a class="tel-btn" target="_blank" href="${msg.url}" onclick="triggerLead();">${msg.text}</a>`;
                } else if (msg.type === 'link-terms') {
                    messageDiv.innerHTML = `
                        <a class="tel-btn" target="_blank" href="${msg.url}" onclick="triggerLead();">${msg.text}</a>
                        <p style="font-size:10px;" class="terms-text">${msg.termsText}</p>
                        `;
                } else if (msg.type === 'image') {
                    messageDiv.innerHTML = `<p><img src="${msg.url}" alt="${msg.text}"/></p>`;
                }

                //botReplyDiv.insertBefore(messageDiv, typingDiv);
                botReplyDiv.appendChild(messageDiv);

                // If it's not the last message, re-append the typing indicator
                // if it doesn't have responses, don't show
                if (index <= totalMessages - 1 && stepData.response) {
                    botReplyDiv.appendChild(typingDiv);
                    typingDiv.style.display = 'block';
                }

                // If it's the last message, add buttons
                if (index === stepData.messages.length - 1) {
                    setTimeout(() => {
                        if (stepData.response) {
                            const buttonContainerDiv = document.createElement('div');
                            if (stepData.buttonLayout) {
                                buttonContainerDiv.className = stepData.buttonLayout === "inline" ? 'chatbox-message btns chat-btn-block' : 'chatbox-message btns-row chat-btn-block';
                            } else {
                                buttonContainerDiv.className = Object.keys(stepData.response).length > 2 ? 'chatbox-message btns-row chat-btn-block' : 'chatbox-message btns chat-btn-block';
                            }

                            Object.keys(stepData.response).forEach(responseText => {
                                const button = document.createElement('button');
                                button.textContent = responseText;
                                button.classList.add("chat-button");
                                button.onclick = () => {
                                    // Hide current response options and show user reply
                                    botReplyDiv.removeChild(buttonContainerDiv);
                                    displayStep(stepData.response[responseText], responseText);
                                };
                                buttonContainerDiv.appendChild(button);
                            });

                            botReplyDiv.appendChild(buttonContainerDiv);
                            scrollToBottom();
                        }
                        typingDiv.style.display = 'none';
                    }, 1000); // Delay increases with each message
                }

                chat.appendChild(botReplyDiv);
                scrollToBottom();
            }, 1000 * (index + 1)); // Delay increases with each message
        };

        // Add typing simulation and process messages
        const totalMessages = stepData.messages.length;
        stepData.messages.forEach((msg, index) => {
            processMessage(msg, index, totalMessages, initialBotReplyDiv);
        });
    } else {
        // Handle end of conversation
        scrollToBottom();
    }
}


function triggerLead() {
    fbq('track', 'Lead');
}

// Initialize chat
displayStep("1");
